@@ -1,4 +1,5 @@
 import os
+import sys
 
 try:
   from google.appengine.api import app_identity
@@ -28,4 +29,7 @@ PREVIEW_DOMAINS = (
     'growlaunches.com',
 )
 
-VERSION = open(os.path.join(os.path.dirname(__file__), '..', 'VERSION')).read().strip()
+try:
+  VERSION = open(os.path.join(sys._MEIPASS, 'VERSION')).read().strip()
+except AttributeError:
+  VERSION = open(os.path.join(os.path.dirname(__file__), '..', 'VERSION')).read().strip()
