@@ -43,21 +43,6 @@ def walk(node, callback):
       callback(item, key, node)
 
 
-def colorize(text):
-  return text.format(**{
-    'blue': '\033[0;34m',
-    '/blue': '\033[0;m',
-    'red': '\033[0;31m',
-    '/red': '\033[0;m',
-    'green': '\033[0;32m',
-    '/green': '\033[0;m',
-    'yellow': '\033[0;33m',
-    '/yellow': '\033[0;m',
-    'white': '\033[0;37m',
-    '/white': '\033[0;m',
-  })
-
-
 def apply_heaers(headers, path):
   mimetype = mimetypes.guess_type(path)[0]
   if mimetype:
