@@ -199,10 +199,7 @@ class Pod(object):
 
     return output
 
-  def dump(self, suffix='index.html', out_dir=None):
-    if out_dir is not None:
-      logging.info('Dumping to {}...'.format(out_dir))
-
+  def dump(self, suffix='index.html'):
     output = self.export()
     clean_output = {}
     if suffix:
@@ -210,12 +207,6 @@ class Pod(object):
         if suffix and path.endswith('/') or '.' not in os.path.basename(path):
           path = path.rstrip('/') + '/' + suffix
         clean_output[path] = content
-        if out_dir is not None:
-          out_path = os.path.join(out_dir, path.lstrip('/'))
-          if isinstance(content, unicode):
-            content = content.encode('utf-8')
-          self.storage.write(out_path, content)
-          logging.info('Dumping: {}'.format(path))
     else:
       clean_output = output
     return clean_output
@@ -234,21 +225,29 @@ class Pod(object):
       self.delete_file(path)
     return pod_paths
 
-  def get_deployment(self, nickname, *args, **kwargs):
+  def list_deployments(self):
+    destination_configs = self.yaml['deployments']
+    results = []
+    for name in destination_configs.keys():
+      results.append(self.get_deployment(name))
+    return results
+
+  def get_deployment(self, nickname):
     """Returns a pod-specific deployment."""
     if 'deployments' not in self.yaml:
       raise ValueError('No pod-specific deployments configured.')
-    deployment_configs = self.yaml['deployments']
-    if nickname not in deployment_configs:
+    destination_configs = self.yaml['deployments']
+    if nickname not in destination_configs:
       text = 'No deployment named {}. Valid deployments: {}.'
-      raise ValueError(text.format(nickname, ', '.join(deployment_configs.keys())))
-    deployment_params = deployment_configs[nickname]
+      raise ValueError(text.format(nickname, ', '.join(destination_configs.keys())))
+    deployment_params = destination_configs[nickname]
     kind = deployment_params.pop('destination')
-    deployment = deployments.Deployment.get(kind, *args, **kwargs)
     try:
-      deployment.set_params(**deployment_params)
-    except TypeError as e:
-      raise ValueError('Invalid deployment params: {}'.format(str(e)))
+      config = destination_configs[nickname]
+      deployment = deployments.make_deployment(kind, config)
+    except TypeError:
+      logging.exception('Invalid deployment parameters.')
+      raise
     return deployment
 
   def list_locales(self):
@@ -281,6 +280,7 @@ class Pod(object):
         loader=_template_loader, autoescape=True, trim_blocks=True,
         extensions=['jinja2.ext.i18n'])
     env.filters['markdown'] = tags.markdown_filter
+    env.filters['render'] = tags.render_filter
     return env
 
   def get_root_path(self, locale=None):
